

#from . import data
#from . import datasets
#from . import evaluation
#from . import models
#from . import metrics
#from . import utils
from . import vis

# Also importable from root
from .experiment import Experiment

__version__ = '0.0.1'

if __name__ == "__main__":
    print("Welcome to RecoFlow")



import numpy as np
import pandas as pd
import altair as alt

# Visualise the metrics from the model
def metrics(history):
    df = pd.DataFrame(history)
    df.reset_index()
    df["batch"] = df.index + 1
    df = df.melt("batch", var_name="name")
    df["val"] = df.name.str.startswith("val")
    df["type"] = df["val"]
    df["metrics"] = df["val"]
    df.loc[df.val == False, "type"] = "training"
    df.loc[df.val == True, "type"] = "validation"
    df.loc[df.val == False, "metrics"] = df.name
    df.loc[df.val == True, "metrics"] = df.name.str.split("val_", expand=True)[1]
    df = df.drop(["name", "val"], axis=1)
    
    base = alt.Chart().encode(
        x = "batch:Q",
        y = "value:Q",
        color = "type"
    ).properties(width = 300, height = 300)

    layers = base.mark_circle(size = 50).encode(tooltip = ["batch", "value"]) + base.mark_line()
    chart = layers.facet(column='metrics:N', data=df).resolve_scale(y='independent')    
    
    return chart


# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['recoflow']

package_data = \
{'': ['*']}

install_requires = \
['altair>=3.2,<4.0',
 'matplotlib>=3.1,<4.0',
 'numpy>=1.17,<2.0',
 'pandas>=0.25.1,<0.26.0',
 'requests>=2.22,<3.0',
 'scikit-learn>=0.21.3,<0.22.0']

setup_kwargs = {
    'name': 'recoflow',
    'version': '0.0.1',
    'description': 'Deep Recommender System for Humans',
    'long_description': '# recoflow\nDeep Recommender System for Humans\n',
    'author': 'Amit Kapoor',
    'author_email': 'amitkaps@gmail.com',
    'url': 'https://github.com/amitkaps/recoflow',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
